==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/util/bedrock/GeyserEntry.java <==
package cc.thonly.reverie_dreams.util.bedrock;

import cc.thonly.reverie_dreams.Touhou;
import cc.thonly.reverie_dreams.util.IdentifierGetter;
import net.fabricmc.fabric.api.event.lifecycle.v1.ServerLifecycleEvents;
import net.minecraft.class_1792;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_5321;
import net.minecraft.class_7923;
import org.geysermc.event.subscribe.Subscribe;
import org.geysermc.geyser.api.GeyserApi;
import org.geysermc.geyser.api.event.EventRegistrar;
import org.geysermc.geyser.api.event.lifecycle.GeyserDefineCustomItemsEvent;
import org.geysermc.geyser.api.item.custom.NonVanillaCustomItemData;

import java.nio.file.Path;
import java.util.Map;

@Deprecated
public class GeyserEntry implements EventRegistrar {
    public static Path PACKS_FOLDER;
    public static Path GEYSER_PACK;
    public static GeyserApi geyser;

    public static void init() {
        ServerLifecycleEvents.SERVER_STARTING.register(minecraftServer -> {
            geyser = GeyserApi.api();

            EventRegistrar registrar = new GeyserEntry();
            geyser.eventBus().register(registrar, registrar);
        });
    }

    @Subscribe
    public void onGeyserDefineCustomItemsEvent(GeyserDefineCustomItemsEvent event) {
        for (Map.Entry<class_5321<class_1792>, class_1792> mapEntry : class_7923.field_41178.method_29722()) {
            class_5321<class_1792> key = mapEntry.getKey();
            if (!key.method_29177().method_12836().equals(Touhou.MOD_ID)) continue;
            class_1792 item = mapEntry.getValue();
            if(item instanceof IdentifierGetter) {
                int id = class_7923.field_41178.method_10206(item);
                class_2960 identifier = ((IdentifierGetter) item).getIdentifier();
                NonVanillaCustomItemData.Builder customItemData = NonVanillaCustomItemData.builder()
                        .displayName(class_2561.method_43471(item.method_7876()).getString())
                        .name(class_2561.method_43471(item.method_7876()).getString())
                        .javaId(id)
                        .stackSize(item.method_7882())
                        .identifier(identifier.toString())
                        .translationString(item.method_7876())
                        .allowOffhand(true)
                        .displayHandheld(true)
                        .icon(identifier.toString())
                        .creativeCategory(3)
                        ;

                event.register(customItemData.build());
            }
        }
    }
    public static boolean isPlayerOnBedrock(class_3222 player) {
        if (geyser == null || player == null) return false;
        return geyser.isBedrockPlayer(player.method_5667());
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/util/bedrock/GeyserEntry.java <==
package cc.thonly.reverie_dreams.util.bedrock;

import cc.thonly.reverie_dreams.ReverieDreams;
import cc.thonly.reverie_dreams.util.IdentifierGetter;
import net.fabricmc.fabric.api.event.lifecycle.v1.ServerLifecycleEvents;
import net.minecraft.class_1792;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_5321;
import net.minecraft.class_7923;
import org.geysermc.event.subscribe.Subscribe;
import org.geysermc.geyser.api.GeyserApi;
import org.geysermc.geyser.api.event.EventRegistrar;
import org.geysermc.geyser.api.event.lifecycle.GeyserDefineCustomItemsEvent;
import org.geysermc.geyser.api.item.custom.NonVanillaCustomItemData;

import java.nio.file.Path;
import java.util.Map;

@Deprecated
public class GeyserEntry implements EventRegistrar {
    public static Path PACKS_FOLDER;
    public static Path GEYSER_PACK;
    public static GeyserApi geyser;

    public static void init() {
        ServerLifecycleEvents.SERVER_STARTING.register(minecraftServer -> {
            geyser = GeyserApi.api();

            EventRegistrar registrar = new GeyserEntry();
            geyser.eventBus().register(registrar, registrar);
        });
    }

    @Subscribe
    public void onGeyserDefineCustomItemsEvent(GeyserDefineCustomItemsEvent event) {
        for (Map.Entry<class_5321<class_1792>, class_1792> mapEntry : class_7923.field_41178.method_29722()) {
            class_5321<class_1792> key = mapEntry.getKey();
            if (!key.method_29177().method_12836().equals(ReverieDreams.MOD_ID)) continue;
            class_1792 item = mapEntry.getValue();
            if(item instanceof IdentifierGetter) {
                int id = class_7923.field_41178.method_10206(item);
                class_2960 identifier = ((IdentifierGetter) item).getIdentifier();
                NonVanillaCustomItemData.Builder customItemData = NonVanillaCustomItemData.builder()
                        .displayName(class_2561.method_43471(item.method_7876()).getString())
                        .name(class_2561.method_43471(item.method_7876()).getString())
                        .javaId(id)
                        .stackSize(item.method_7882())
                        .identifier(identifier.toString())
                        .translationString(item.method_7876())
                        .allowOffhand(true)
                        .displayHandheld(true)
                        .icon(identifier.toString())
                        .creativeCategory(3)
                        ;

                event.register(customItemData.build());
            }
        }
    }
    public static boolean isPlayerOnBedrock(class_3222 player) {
        if (geyser == null || player == null) return false;
        return geyser.isBedrockPlayer(player.method_5667());
    }
}
